# CONTRIBUTIONS and CODE REVIEWS

We love contributions from the community. Please send pull requests and raise
issues! All code submissions require review. We use GitHub pull requests for
this purpose.

> **Note** Contributions that were generated in whole or in-part from any
> language model or AI, such as GitHub Copilot, ChatGPT, BARD, or any other such tool
> are explicitly forbidden and will result in your permanent ban from contributing
> to this project.


# COPYRIGHTS and LICENSE

Torii HDL is licensed under the 2-clause BSD license, which is contained in
the LICENSE file.

All authors retain copyright ownership of their contributions.

Authors should note that all contributions are licensed under the 2-clause BSD
license.


# CONTRIBUTORS

The complete list of contributors is contained within the git repository.
Tools such as the git log command can be used to see all contributions and
contributors.
